package com.winhc.bigdata.spark.ng.jobs

import com.winhc.bigdata.spark.ng.utils.explode_args

/**
 * @author: XuJiakai
 * @date: 2021/1/14 19:21
 */
case class args_company_job(tableName: String
                            , md5_fields: Seq[String] //该维度的核心字段
                            , rowkey_add_company_id: Boolean = true //如果存在company_id,是否将company_id作为rowkey前辍
                            , rowkey_udf: String = null //用于自定义rowkey的结构，会覆盖md5_fields的默认rowkey
                            , is_super_filter: Boolean = true //是否开启超级过滤,超级过滤后任一主键都不允许为空
                            , where: String = "" // ods层数据的过滤条件
                            , id_user_defined_rowkey: Boolean = false //是否读取ods层的用户自定义rowkey
                            , verify_company_id: Boolean = true
                            , explode_args: Seq[explode_args] = null //如果表需要炸开，则配制此项
                           )

object args_company_job {
  val tab_md5_fields = Seq(
    args_company_job("company_app_info", Seq("name"))
    , args_company_job("company_staff", Seq("staff_name"))
    , args_company_job("company_holder", Seq("holder_name"), rowkey_udf = "concat_ws('_',company_id,md5(cleanup(concat_ws('',holder_switch_rowkey(holder_type,holder_id,holder_name)))))", where = " holder_name is not null and trim(holder_name) <> '' AND ( not (holder_type = 2 AND length(holder_id) <> 32)) ")
    , args_company_job("company_icp", Seq("liscense", "domain"))
    , args_company_job("company_tm", Seq("reg_no"))

    , args_company_job("company_court_open_announcement", Seq("case_no", "start_date")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no_trim(case_no),split_date(cast(start_date as String)) )))"
      , is_super_filter = false
      , where = "case_no_trim(case_no) is not null and is_json_str(defendant_info) and is_json_str(plaintiff_info) and is_json_str(litigant_info)"
      , explode_args = Seq(
        explode_args("plaintiff_info", "$.litigant_id", "plaintiff_info_id_explode")
        , explode_args("defendant_info", "$.litigant_id", "defendant_info_id_explode")
      )
    )
    , args_company_job("company_court_announcement", Seq("case_no", "announcement_type", "publish_date", "court_name")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no_trim(case_no),announcement_type,split_date(cast(publish_date as String)),court_name )))"
      , is_super_filter = false
      , where = "is_json_str(plaintiff_info) and is_json_str(litigant_info)"
      , explode_args = Seq(
        explode_args("plaintiff_info", "$.litigant_id", "plaintiff_info_id_explode")
        , explode_args("litigant_info", "$.litigant_id", "litigant_info_id_explode")
      )
    )
    , args_company_job("company_send_announcement", Seq("court", "start_date", "title")
      , rowkey_udf = "md5(cleanup(concat_ws('',court,split_date(cast(start_date as String)),title )))"
      , is_super_filter = false
      , where = "is_json_str(litigant_info) and is_json_str(defendant_info) and is_json_str(plaintiff_info)"
      , explode_args = Seq(
        explode_args("plaintiff_info", "$.litigant_id", "plaintiff_info_id_explode")
        , explode_args("defendant_info", "$.litigant_id", "defendant_info_id_explode")
      )
    )
    , args_company_job("company_court_register", Seq("case_no", "filing_date")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no_trim(case_no),split_date(cast(filing_date as String)) )))"
      , is_super_filter = false
      , where = "is_json_str(litigant_info) and is_json_str(defendant_info) and is_json_str(plaintiff_info)"
      , explode_args = Seq(
        explode_args("plaintiff_info", "$.litigant_id", "plaintiff_info_id_explode")
        , explode_args("defendant_info", "$.litigant_id", "defendant_info_id_explode")
      )
    )
    , args_company_job("company_zxr_final_case", Seq("case_no")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_no )))"
      , is_super_filter = false
    )
    , args_company_job("company_tax_contravention", Seq("case_info", "company_id")
      , rowkey_udf = "md5(cleanup(concat_ws('',case_info,company_id )))"
      , is_super_filter = false
    )
    , args_company_job("company_own_tax", Seq("tax_balance", "tax_category", "company_id")
      , rowkey_udf = "md5(cleanup(concat_ws('',tax_balance,tax_category,company_id )))"
      , is_super_filter = false
    )
    , args_company_job("company_check_info", Seq("check_type", "check_result", "check_org","check_date","company_id")
      , rowkey_udf = "md5(cleanup(concat_ws('',check_type,check_result,check_org,split_date(cast(check_date as String)),company_id )))"
      , is_super_filter = false
    )
  )


  def get_args_company_job(tn: String): args_company_job = {
    tab_md5_fields.find(p => tn.equals(p.tableName)).getOrElse(throw new NullPointerException("tn is not fount"))
  }
}
